@@ -65,7 +65,7 @@ class Device:
             if resp:
                 self.dev_info.dps[str(power_ability.id)] = state
 
-    async def get_power_state(self) -> bool:
+    def get_power_state(self) -> bool:
         if Capability.SWITCH_LED in self.capabilities:
             power_ability = self.capabilities[Capability.SWITCH_LED]
             return self.dev_info.dps[str(power_ability.id)]
@@ -88,7 +88,7 @@ class Device:
             if resp:
                 self.dev_info.dps[str(bright_ability.id)] = nbright
 
-    async def get_brightness(self) -> int:
+    def get_brightness(self) -> int:
         if Capability.BRIGHT_VALUE in self.capabilities:
             bright_ability = self.capabilities[Capability.BRIGHT_VALUE]
             min = bright_ability.property.min
